@@ -28,6 +28,7 @@ __all__ = (
     "DmsTransferSettingsTypeDef",
     "DynamoDbSettingsTypeDef",
     "ElasticsearchSettingsTypeDef",
+    "KafkaSettingsTypeDef",
     "KinesisSettingsTypeDef",
     "MongoDbSettingsTypeDef",
     "RedshiftSettingsTypeDef",
@@ -153,9 +154,20 @@ class ElasticsearchSettingsTypeDef(
     pass
 
 
+KafkaSettingsTypeDef = TypedDict("KafkaSettingsTypeDef", {"Broker": str, "Topic": str}, total=False)
+
 KinesisSettingsTypeDef = TypedDict(
     "KinesisSettingsTypeDef",
-    {"StreamArn": str, "MessageFormat": Literal["json"], "ServiceAccessRoleArn": str},
+    {
+        "StreamArn": str,
+        "MessageFormat": Literal["json", "json-unformatted"],
+        "ServiceAccessRoleArn": str,
+        "IncludeTransactionDetails": bool,
+        "IncludePartitionValue": bool,
+        "PartitionIncludeSchemaTable": bool,
+        "IncludeTableAlterOperations": bool,
+        "IncludeControlDetails": bool,
+    },
     total=False,
 )
 
@@ -233,6 +245,7 @@ S3SettingsTypeDef = TypedDict(
         "CdcInsertsOnly": bool,
         "TimestampColumnName": str,
         "ParquetTimestampInMillisecond": bool,
+        "CdcInsertsAndUpdates": bool,
     },
     total=False,
 )
@@ -262,6 +275,7 @@ EndpointTypeDef = TypedDict(
         "DmsTransferSettings": DmsTransferSettingsTypeDef,
         "MongoDbSettings": MongoDbSettingsTypeDef,
         "KinesisSettings": KinesisSettingsTypeDef,
+        "KafkaSettings": KafkaSettingsTypeDef,
         "ElasticsearchSettings": ElasticsearchSettingsTypeDef,
         "RedshiftSettings": RedshiftSettingsTypeDef,
     },
@@ -676,6 +690,9 @@ TableStatisticsTypeDef = TypedDict(
         "FullLoadRows": int,
         "FullLoadCondtnlChkFailedRows": int,
         "FullLoadErrorRows": int,
+        "FullLoadStartTime": datetime,
+        "FullLoadEndTime": datetime,
+        "FullLoadReloaded": bool,
         "LastUpdateTime": datetime,
         "TableState": str,
         "ValidationPendingRecords": int,
